==> dwf-deploy-2.6.6.tgz: package/lib/dwf/object/type/abstract.js <==
'use strict'

const coRequestLib = require('../../request.js')
const coLoggerLib = require('../../../logger.js')
const coDwfAbstract = require('../../abstract.js')

// const coRepositoryLib = require('../../repository.js')

const abstract = {}

abstract.cnError = 2
abstract.cnSuccess = 0
abstract.cnWarning = 1

abstract.csKey_AOI_nID = 'sID'
abstract.csKey_AOI_sFile = 'sFile'
abstract.csKey_nStatus = 'nStatus'
abstract.csKey_AOI_Action = 'sAction'
abstract.csKey_AOI_TYPE_ID = 'TYPE_ID'
abstract.csKey_AOI_nStatus = 'nStatus'
abstract.csKey_AOI_sNamespace = 'sNamespace'
abstract.csKey_AOI_csNamespace = 'namespace'
abstract.csKey_sDescription = 'sDescription'
abstract.csKey_o_sExt2aoItem = 'o_sExt2aoItem'
abstract.csKey_o_sExt2oValue = 'o_sExt2oValue'
abstract.csKey_AOI_sDescription = 'sDescription'
abstract.csKey_AOI_Task_chain_Id = 'taskChainId'
abstract.csKey_AOI_DLM_Profile_Id = 'dlmprofileId'
abstract.csKey_AOI_sHashUtf8Sha256Hex = 'sHashUtf8Sha256Hex'

abstract.coColumn = {
  '.dwftaskchain': abstract.csKey_AOI_Task_chain_Id,
  '.dwfdlmprofile': abstract.csKey_AOI_DLM_Profile_Id
}
abstract.Methods = { GET: 'GET', POST: 'POST', DELETE: 'DELETE' }
abstract.TYPES = { OBJECTS: 'objects', PROVIDERS: 'providers', OBJECT_TYPES: 'objectTypes' }
abstract.PROVIDER_ACTION = { SKIP: 'SKIP', POST: 'POST', DELETE: 'DELETE' }
abstract.cfPrepare = 'fPrepare'
abstract.csExtention = 'sExtention'
abstract.cfCreateTasks = 'fCreateTasks'
abstract.cfIsDeployable = 'fIsDeployable'
abstract.cfCommonObjectProperties = 'fCommonObjectProperties'

abstract.cfGetProvider = function (aoProviders, isExtensionFile) {
  const loProviderExt = {}
  aoProviders.forEach(function (ioProvider) { // Check - ioProvider schema validation
    const laoExtentions = ioProvider.extensions
    laoExtentions.forEach(function (ioExtension) {
      const lsExtensionName = ioExtension.name
      const lsExtensionRoute = ioExtension.route
      if (isExtensionFile === '.' + lsExtensionName) {
        loProviderExt.org = ioProvider.org
        loProviderExt.org_guid = ioProvider.org_guid
        loProviderExt.space = ioProvider.space
        loProviderExt.space_guid = ioProvider.space_guid
        loProviderExt.name = ioProvider.name
        loProviderExt.url = ioProvider.url + '/' + lsExtensionRoute
        loProviderExt.extention = lsExtensionName
        loProviderExt.route = lsExtensionRoute
      }
    })
  })
  if (typeof loProviderExt.url === 'undefined' || loProviderExt.url === null) {
    throw new Error('Failed, because was not able to construct the url for the service provider for ' + isExtensionFile + ' files')
  }
  return loProviderExt
}
abstract.lfCb2Reuse = function (isExt, ioData, ifCb) {
  return function (ioError, ioResponse, ioBody) {
    const lsExt = isExt
    const loData = ioData
    const lfCb = ifCb
    let loError
    if (typeof ioError !== 'undefined' && ioError !== null) {
      loError = ioError
    } else if (ioResponse.statusCode !== 200) {
      loError = new Error('Failed, because ' + loData.method + ' on ' + loData.uri + ' returned ' + ioResponse.statusCode +
        ' as a response status code with body ' + JSON.stringify(ioBody))
    }
    if (typeof loError === 'undefined' || loError === null) {
      coLoggerLib.log(' * ' + lsExt + ' - ' + loData.uri + ' ' + loData.method + ' ... ok' + '(' + ioResponse.statusCode + ')')
    }
    lfCb(loError, ioResponse)
  }
}
abstract.fpreparePost = function (isExt, iaObjects, ioProviderExt, ioCredential, isMethod) {
  const loDataRequest = {
    uri: ioProviderExt.url,
    json: true,
    method: isMethod,
    auth: {
      user: ioCredential.user,
      password: ioCredential.password,
      sendImmediately: true
    },
    body: iaObjects
  }
  const lfTask = function (ifCb) {
    coLoggerLib.trace(' *  ' + isExt + ' - ' + loDataRequest.uri + ' ' + loDataRequest.method + ' ... ')
    const lfcb = abstract.lfCb2Reuse(isExt, loDataRequest, ifCb)
    coRequestLib(loDataRequest, lfcb)
  }
  const lafTask = []
  if (iaObjects.length > 0) {
    lafTask.push(lfTask)
  }
  return lafTask
}
abstract.fGetProvider = function (ioCredential, isExt) {
  const loProviderExt = abstract.cfGetProvider(ioCredential[coDwfAbstract.cs_Credential_Key_Providers_v1], isExt)
  const loProvider = {
    ORG: loProviderExt.org,
    ORG_GUID: loProviderExt.org_guid,
    SPACE: loProviderExt.space,
    SPACE_GUID: loProviderExt.space_guid,
    ID: loProviderExt.name
  }
  return loProvider
}
abstract.fGetObjectType = function (ioCredential, isExt) {
  const loProviderExt = abstract.cfGetProvider(ioCredential[coDwfAbstract.cs_Credential_Key_Providers_v1], isExt)
  const loObjectType = {
    ID: loProviderExt.extention,
    URL_ROUTE: loProviderExt.route,
    PROVIDER_ID: loProviderExt.name,
    PROVIDER_ORG: loProviderExt.org,
    PROVIDER_ORG_GUID: loProviderExt.org_guid,
    PROVIDER_SPACE: loProviderExt.space,
    PROVIDER_SPACE_GUID: loProviderExt.space_guid
  }
  return loObjectType
}
abstract.fGetProviderORObjectType = function (ioCredential, isID) {
  const aoProviders = ioCredential[coDwfAbstract.cs_Credential_Key_Providers_v1]
  let o2Return = {}
  aoProviders.forEach(function (ioProvider) { // Check - ioProvider schema validation
    if (ioProvider.name === isID) {
      const laoExtentions = ioProvider.extensions
      laoExtentions.forEach(function (ioExtension) {
        o2Return = {
          ID: ioExtension.name,
          URL_ROUTE: ioExtension.route,
          PROVIDER_ID: ioProvider.name,
          PROVIDER_ORG: ioProvider.org,
          PROVIDER_ORG_GUID: ioProvider.org_guid,
          PROVIDER_SPACE: ioProvider.space,
          PROVIDER_SPACE_GUID: ioProvider.space_guid
        }
      })
    } else {
      const laoExtentions = ioProvider.extensions
      laoExtentions.forEach(function (ioExtension) {
        const lsExtensionName = ioExtension.name
        if (isID === '.' + lsExtensionName) {
          o2Return = {
            ORG: ioProvider.org,
            ORG_GUID: ioProvider.org_guid,
            SPACE: ioProvider.space,
            SPACE_GUID: ioProvider.space_guid,
            ID: ioProvider.name
          }
        }
      })
    }
  })
  return o2Return
}

module.exports = abstract

==> dwf-deploy-2.7.2.tgz: package/lib/dwf/object/type/abstract.js <==
'use strict'

const coRequestLib = require('../../request.js')
const coLoggerLib = require('../../../logger.js')
const coDwfAbstract = require('../../abstract.js')

// const coRepositoryLib = require('../../repository.js')

const abstract = {}

abstract.cnError = 2
abstract.cnSuccess = 0
abstract.cnWarning = 1

abstract.csKey_AOI_nID = 'sID'
abstract.csKey_AOI_sFile = 'sFile'
abstract.csKey_nStatus = 'nStatus'
abstract.csKey_AOI_Action = 'sAction'
abstract.csKey_AOI_TYPE_ID = 'TYPE_ID'
abstract.csKey_AOI_nStatus = 'nStatus'
abstract.csKey_AOI_sNamespace = 'sNamespace'
abstract.csKey_AOI_csNamespace = 'namespace'
abstract.csKey_sDescription = 'sDescription'
abstract.csKey_o_sExt2aoItem = 'o_sExt2aoItem'
abstract.csKey_o_sExt2oValue = 'o_sExt2oValue'
abstract.csKey_AOI_sDescription = 'sDescription'
abstract.csKey_AOI_Task_chain_Id = 'taskChainId'
abstract.csKey_AOI_DLM_Profile_Id = 'dlmprofileId'
abstract.csKey_AOI_sHashUtf8Sha256Hex = 'sHashUtf8Sha256Hex'

abstract.coColumn = {
  '.dwftaskchain': abstract.csKey_AOI_Task_chain_Id,
  '.dwfdlmprofile': abstract.csKey_AOI_DLM_Profile_Id
}
abstract.Methods = { GET: 'GET', POST: 'POST', DELETE: 'DELETE' }
abstract.TYPES = { OBJECTS: 'objects', PROVIDERS: 'providers', OBJECT_TYPES: 'objectTypes' }
abstract.PROVIDER_ACTION = { SKIP: 'SKIP', POST: 'POST', DELETE: 'DELETE' }
abstract.cfPrepare = 'fPrepare'
abstract.csExtention = 'sExtention'
abstract.cfCreateTasks = 'fCreateTasks'
abstract.cfIsDeployable = 'fIsDeployable'
abstract.cfCommonObjectProperties = 'fCommonObjectProperties'

abstract.cfGetProvider = function (aoProviders, isExtensionFile) {
  const loProviderExt = {}
  aoProviders.forEach(function (ioProvider) { // Check - ioProvider schema validation
    const laoExtentions = ioProvider.extensions
    laoExtentions.forEach(function (ioExtension) {
      const lsExtensionName = ioExtension.name
      const lsExtensionRoute = ioExtension.route
      if (isExtensionFile === '.' + lsExtensionName) {
        loProviderExt.org = ioProvider.org
        loProviderExt.org_guid = ioProvider.org_guid
        loProviderExt.space = ioProvider.space
        loProviderExt.space_guid = ioProvider.space_guid
        loProviderExt.name = ioProvider.name
        loProviderExt.url = ioProvider.url + '/' + lsExtensionRoute
        loProviderExt.extention = lsExtensionName
        loProviderExt.route = lsExtensionRoute
      }
    })
  })
  if (typeof loProviderExt.url === 'undefined' || loProviderExt.url === null) {
    throw new Error('Failed, because was not able to construct the url for the service provider for ' + isExtensionFile + ' files')
  }
  return loProviderExt
}
abstract.lfCb2Reuse = function (isExt, ioData, ifCb) {
  return function (ioError, ioResponse, ioBody) {
    const lsExt = isExt
    const loData = ioData
    const lfCb = ifCb
    let loError
    if (typeof ioError !== 'undefined' && ioError !== null) {
      loError = ioError
    } else if (ioResponse.status !== 200) {
      loError = new Error('Failed, because ' + loData.method + ' on ' + loData.url + ' returned ' + ioResponse.status +
        ' as a response status code with body ' + JSON.stringify(ioBody))
    }
    if (typeof loError === 'undefined' || loError === null) {
      coLoggerLib.log(' * ' + lsExt + ' - ' + loData.url + ' ' + loData.method + ' ... ok' + '(' + ioResponse.status + ')')
    }
    lfCb(loError, ioResponse)
  }
}
abstract.fpreparePost = function (isExt, iaObjects, ioProviderExt, ioCredential, isMethod) {
  const loDataRequest = {
    url: ioProviderExt.url,
    json: true,
    method: isMethod,
    auth: {
      username: ioCredential.user,
      password: ioCredential.password,
      sendImmediately: true
    },
    data: iaObjects
  }
  const lfTask = function (ifCb) {
    coLoggerLib.trace(' *  ' + isExt + ' - ' + loDataRequest.url + ' ' + loDataRequest.method + ' ... ')
    const lfcb = abstract.lfCb2Reuse(isExt, loDataRequest, ifCb)
    coRequestLib(loDataRequest, lfcb)
  }
  const lafTask = []
  if (iaObjects.length > 0) {
    lafTask.push(lfTask)
  }
  return lafTask
}
abstract.fGetProvider = function (ioCredential, isExt) {
  const loProviderExt = abstract.cfGetProvider(ioCredential[coDwfAbstract.cs_Credential_Key_Providers_v1], isExt)
  const loProvider = {
    ORG: loProviderExt.org,
    ORG_GUID: loProviderExt.org_guid,
    SPACE: loProviderExt.space,
    SPACE_GUID: loProviderExt.space_guid,
    ID: loProviderExt.name
  }
  return loProvider
}
abstract.fGetObjectType = function (ioCredential, isExt) {
  const loProviderExt = abstract.cfGetProvider(ioCredential[coDwfAbstract.cs_Credential_Key_Providers_v1], isExt)
  const loObjectType = {
    ID: loProviderExt.extention,
    URL_ROUTE: loProviderExt.route,
    PROVIDER_ID: loProviderExt.name,
    PROVIDER_ORG: loProviderExt.org,
    PROVIDER_ORG_GUID: loProviderExt.org_guid,
    PROVIDER_SPACE: loProviderExt.space,
    PROVIDER_SPACE_GUID: loProviderExt.space_guid
  }
  return loObjectType
}
abstract.fGetProviderORObjectType = function (ioCredential, isID) {
  const aoProviders = ioCredential[coDwfAbstract.cs_Credential_Key_Providers_v1]
  let o2Return = {}
  aoProviders.forEach(function (ioProvider) { // Check - ioProvider schema validation
    if (ioProvider.name === isID) {
      const laoExtentions = ioProvider.extensions
      laoExtentions.forEach(function (ioExtension) {
        o2Return = {
          ID: ioExtension.name,
          URL_ROUTE: ioExtension.route,
          PROVIDER_ID: ioProvider.name,
          PROVIDER_ORG: ioProvider.org,
          PROVIDER_ORG_GUID: ioProvider.org_guid,
          PROVIDER_SPACE: ioProvider.space,
          PROVIDER_SPACE_GUID: ioProvider.space_guid
        }
      })
    } else {
      const laoExtentions = ioProvider.extensions
      laoExtentions.forEach(function (ioExtension) {
        const lsExtensionName = ioExtension.name
        if (isID === '.' + lsExtensionName) {
          o2Return = {
            ORG: ioProvider.org,
            ORG_GUID: ioProvider.org_guid,
            SPACE: ioProvider.space,
            SPACE_GUID: ioProvider.space_guid,
            ID: ioProvider.name
          }
        }
      })
    }
  })
  return o2Return
}

module.exports = abstract
